@@ -12,7 +12,7 @@ from beziers.path.representations.fontparts import FontParts
 
 __author__ = """Simon Cozens"""
 __email__ = "simon@simon-cozens.org"
-__version__ = "__version__ = '0.7.1'"
+__version__ = "__version__ = '0.7.2'"
 
 
 def categorize_glyph(font, glyphname):
@@ -32,7 +32,10 @@ def categorize_glyph(font, glyphname):
     if glyphtools.glyphs.isglyphs(font):
         return glyphtools.glyphs.categorize_glyph(font, glyphname)
     if glyphtools.babelfont.isbabelfont(font):
-        return (font[glyphname].category, None)
+        if glyphtools.babelfont.isbabelfont3(font):
+            return (font.glyphs[glyphname].category, None)
+        else:
+            return (font[glyphname].category, None)
     if "GDEF" not in font:
         return ("unknown", None)
     gdef = font["GDEF"].table
